@@ -5,8 +5,35 @@ import random
 import sys
 import unittest
 import verifyutils
-from six.moves import map
-from six.moves import range
+
+# FIXME:  why is this required?
+import pkg_resources
+
+
+#
+# mock import statement to correctly load python implemention
+#
+
+
+try:
+    import builtins
+except ImportError:
+    import __builtin__ as builtins
+else:
+    from importlib import reload
+
+realimport = builtins.__import__
+
+
+def no_c_library(name, globals=None, locals=None, fromlist=(), level=0):
+    if name == '__segments':  # refuse to load C segments library
+        raise ImportError
+    return realimport(
+        name,
+        globals=globals,
+        locals=locals,
+        fromlist=fromlist,
+        level=level)
 
 
 #
@@ -67,6 +94,17 @@ def set2():
 
 
 class test_infinity(unittest.TestCase):
+	def test_math(self):
+		a = segments.infinity()
+		self.assertEqual(-a, -a)
+		self.assertLess(-a, 0)
+		self.assertLess(-a, a)
+		self.assertGreater(0, -a)
+		self.assertLess(0, a)
+		self.assertGreater(a, -a)
+		self.assertGreater(a, 0)
+		self.assertEqual(a, a)
+
 	@unittest.skipIf(sys.version_info.major >= 3,
 		'Python 3 does not have cmp')
 	def test__cmp__(self):
@@ -445,7 +483,8 @@ class test_segmentlist(unittest.TestCase):
 
 		for op in ("|", "&", "-", "^"):
 			for arg1, arg2 in (
-				(w, x), (x, w),
+				# FIXME:  how should these behave?
+				#(w, x), (x, w),
 				(w, z), (z, w)
 			):
 				expr = "%s %s %s" % (arg1, op, arg2)
@@ -499,7 +538,12 @@ class test_segmentlistdict(unittest.TestCase):
 if __name__ == "__main__":
 	# first with the pure Python segments implementation
 
-	from ligo import segments
+	builtins.__import__ = no_c_library  # refuse to load C library
+	try:
+		from ligo import segments
+	finally:
+		# reinstate original import
+		builtins.__import__ = realimport
 	verifyutils.segments = segments
 
 	suite = unittest.TestSuite()
@@ -517,12 +561,12 @@ if __name__ == "__main__":
 
 	# then with C extension implementation
 
-	from ligo import __segments
-	segments.infinity = __segments.infinity
-	segments.NegInfinity = __segments.NegInfinity
-	segments.PosInfinity = __segments.PosInfinity
-	segments.segment = __segments.segment
-	segments.segmentlist = __segments.segmentlist
+	reload(segments)  # loads C library and executes copyreg.pickle
+	segments.infinity = segments.infinity
+	segments.NegInfinity = segments.NegInfinity
+	segments.PosInfinity = segments.PosInfinity
+	segments.segment = segments.segment
+	segments.segmentlist = segments.segmentlist
 
 	suite = unittest.TestSuite()
 	suite.addTest(unittest.makeSuite(test_infinity))
